@@ -4,7 +4,7 @@ use 5.012;
 use Encode();
 use Time::HiRes();
 
-our $VERSION = '1.1.3';
+our $VERSION = '1.1.4';
 
 use Panda::Export
     MERGE_ARRAY_CONCAT => 1,
@@ -25,16 +25,15 @@ Panda::XSLoader::bootstrap();
 sub timeout {
     my ($sub, $timeout) = @_;
     if (state $in_debugger = defined $DB::header) { $sub->(); return 1 }
-    my ($ok, $alarm);
+    my ($ok, $alarm, $error);
     local $SIG{ALRM} = sub {$alarm = 1; die "ALARM!"};
     Time::HiRes::alarm($timeout || 1);
     eval {
-        $ok = eval { $sub->(); 1 };
-        die $@ if !$ok and !$alarm;
+        eval { $sub->(); 1 } or do { $error = $@ };
         Time::HiRes::alarm(0);
     };
     return if $alarm;
-    die $@ if !$ok;
+    die $error if $error;
     return 1;
 }
 
